==> deepeval-1.1.5.tar.gz: deepeval-1.1.5/deepeval/benchmarks/hellaswag/task.py <==
from enum import Enum


class HellaSwagTask(Enum):
    APPLYING_SUNSCREEN = "Applying sunscreen"
    TRIMMING_BRANCHES_OR_HEDGES = "Trimming branches or hedges"
    DISC_DOG = "Disc dog"
    WAKEBOARDING = "Wakeboarding"
    SKATEBOARDING = "Skateboarding"
    WATERSKIING = "Waterskiing"
    WASHING_HANDS = "Washing hands"
    SAILING = "Sailing"
    PLAYING_CONGAS = "Playing congas"
    BALLET = "Ballet"
    ROOF_SHINGLE_REMOVAL = "Roof shingle removal"
    HAND_CAR_WASH = "Hand car wash"
    KITE_FLYING = "Kite flying"
    PLAYING_POOL = "Playing pool"
    PLAYING_LACROSSE = "Playing lacrosse"
    LAYUP_DRILL_IN_BASKETBALL = "Layup drill in basketball"
    HOME_AND_GARDEN = "Home and Garden"
    PLAYING_BEACH_VOLLEYBALL = "Playing beach volleyball"
    CALF_ROPING = "Calf roping"
    SCUBA_DIVING = "Scuba diving"
    MIXING_DRINKS = "Mixing drinks"
    PUTTING_ON_SHOES = "Putting on shoes"
    MAKING_A_LEMONADE = "Making a lemonade"
    UNCATEGORIZED = "Uncategorized"
    ZUMBA = "Zumba"
    PLAYING_BADMINTON = "Playing badminton"
    PLAYING_BAGPIPES = "Playing bagpipes"
    FOOD_AND_ENTERTAINING = "Food and Entertaining"
    PERSONAL_CARE_AND_STYLE = "Personal Care and Style"
    CRICKET = "Cricket"
    SHOVELING_SNOW = "Shoveling snow"
    PING_PONG = "Ping-pong"
    HOLIDAYS_AND_TRADITIONS = "Holidays and Traditions"
    ICE_FISHING = "Ice fishing"
    BEACH_SOCCER = "Beach soccer"
    TABLE_SOCCER = "Table soccer"
    SWIMMING = "Swimming"
    BATON_TWIRLING = "Baton twirling"
    JAVELIN_THROW = "Javelin throw"
    SHOT_PUT = "Shot put"
    DOING_CRUNCHES = "Doing crunches"
    POLISHING_SHOES = "Polishing shoes"
    TRAVEL = "Travel"
    USING_UNEVEN_BARS = "Using uneven bars"
    PLAYING_HARMONICA = "Playing harmonica"
    RELATIONSHIPS = "Relationships"
    HIGH_JUMP = "High jump"
    MAKING_A_SANDWICH = "Making a sandwich"
    POWERBOCKING = "Powerbocking"
    REMOVING_ICE_FROM_CAR = "Removing ice from car"
    SHAVING = "Shaving"
    SHARPENING_KNIVES = "Sharpening knives"
    WELDING = "Welding"
    USING_PARALLEL_BARS = "Using parallel bars"
    HOME_CATEGORIES = "Home,Categories"
    ROCK_CLIMBING = "Rock climbing"
    SNOW_TUBING = "Snow tubing"
    WASHING_FACE = "Washing face"
    ASSEMBLING_BICYCLE = "Assembling bicycle"
    TENNIS_SERVE_WITH_BALL_BOUNCING = "Tennis serve with ball bouncing"
    SHUFFLEBOARD = "Shuffleboard"
    DODGEBALL = "Dodgeball"
    CAPOEIRA = "Capoeira"
    PAINTBALL = "Paintball"
    DOING_A_POWERBOMB = "Doing a powerbomb"
    DOING_MOTOCROSS = "Doing motocross"
    PLAYING_ICE_HOCKEY = "Playing ice hockey"
    PHILOSOPHY_AND_RELIGION = "Philosophy and Religion"
    ARCHERY = "Archery"
    CARS_AND_OTHER_VEHICLES = "Cars & Other Vehicles"
    RUNNING_A_MARATHON = "Running a marathon"
    THROWING_DARTS = "Throwing darts"
    PAINTING_FURNITURE = "Painting furniture"
    HAVING_AN_ICE_CREAM = "Having an ice cream"
    SLACKLINING = "Slacklining"
    CAMEL_RIDE = "Camel ride"
    ARM_WRESTLING = "Arm wrestling"
    HULA_HOOP = "Hula hoop"
    SURFING = "Surfing"
    PLAYING_PIANO = "Playing piano"
    GARGLING_MOUTHWASH = "Gargling mouthwash"
    PLAYING_ACCORDION = "Playing accordion"
    HORSEBACK_RIDING = "Horseback riding"
    PUTTING_IN_CONTACT_LENSES = "Putting in contact lenses"
    PLAYING_SAXOPHONE = "Playing saxophone"
    FUTSAL = "Futsal"
    LONG_JUMP = "Long jump"
    LONGBOARDING = "Longboarding"
    POLE_VAULT = "Pole vault"
    BUILDING_SANDCASTLES = "Building sandcastles"
    PLATFORM_DIVING = "Plataform diving"
    PAINTING = "Painting"
    SPINNING = "Spinning"
    CARVING_JACK_O_LANTERNS = "Carving jack-o-lanterns"
    BRAIDING_HAIR = "Braiding hair"
    YOUTH = "Youth"
    PLAYING_VIOLIN = "Playing violin"
    CANOEING = "Canoeing"
    CHEERLEADING = "Cheerleading"
    PETS_AND_ANIMALS = "Pets and Animals"
    KAYAKING = "Kayaking"
    CLEANING_SHOES = "Cleaning shoes"
    KNITTING = "Knitting"
    BAKING_COOKIES = "Baking cookies"
    DOING_FENCING = "Doing fencing"
    PLAYING_GUITARRA = "Playing guitarra"
    USING_THE_ROWING_MACHINE = "Using the rowing machine"
    GETTING_A_HAIRCUT = "Getting a haircut"
    MOOPING_FLOOR = "Mooping floor"
    RIVER_TUBING = "River tubing"
    CLEANING_SINK = "Cleaning sink"
    GROOMING_DOG = "Grooming dog"
    DISCUS_THROW = "Discus throw"
    CLEANING_WINDOWS = "Cleaning windows"
    FINANCE_AND_BUSINESS = "Finance and Business"
    HANGING_WALLPAPER = "Hanging wallpaper"
    ROPE_SKIPPING = "Rope skipping"
    WINDSURFING = "Windsurfing"
    KNEELING = "Kneeling"
    GETTING_A_PIERCING = "Getting a piercing"
    ROCK_PAPER_SCISSORS = "Rock-paper-scissors"
    SPORTS_AND_FITNESS = "Sports and Fitness"
    BREAKDANCING = "Breakdancing"
    WALKING_THE_DOG = "Walking the dog"
    PLAYING_DRUMS = "Playing drums"
    PLAYING_WATER_POLO = "Playing water polo"
    BMX = "BMX"
    SMOKING_A_CIGARETTE = "Smoking a cigarette"
    BLOWING_LEAVES = "Blowing leaves"
    BULLFIGHTING = "Bullfighting"
    DRINKING_COFFEE = "Drinking coffee"
    BATHING_DOG = "Bathing dog"
    TANGO = "Tango"
    WRAPPING_PRESENTS = "Wrapping presents"
    PLASTERING = "Plastering"
    PLAYING_BLACKJACK = "Playing blackjack"
    FUN_SLIDING_DOWN = "Fun sliding down"
    WORK_WORLD = "Work World"
    TRIPLE_JUMP = "Triple jump"
    TUMBLING = "Tumbling"
    SKIING = "Skiing"
    DOING_KICKBOXING = "Doing kickboxing"
    BLOW_DRYING_HAIR = "Blow-drying hair"
    DRUM_CORPS = "Drum corps"
    SMOKING_HOOKAH = "Smoking hookah"
    MOWING_THE_LAWN = "Mowing the lawn"
    VOLLEYBALL = "Volleyball"
    LAYING_TILE = "Laying tile"
    STARTING_A_CAMPFIRE = "Starting a campfire"
    SUMO = "Sumo"
    HURLING = "Hurling"
    PLAYING_KICKBALL = "Playing kickball"
    MAKING_A_CAKE = "Making a cake"
    FIXING_THE_ROOF = "Fixing the roof"
    PLAYING_POLO = "Playing polo"
    REMOVING_CURLERS = "Removing curlers"
    ELLIPTICAL_TRAINER = "Elliptical trainer"
    HEALTH = "Health"
    SPREAD_MULCH = "Spread mulch"
    CHOPPING_WOOD = "Chopping wood"
    BRUSHING_TEETH = "Brushing teeth"
    USING_THE_POMMEL_HORSE = "Using the pommel horse"
    SNATCH = "Snatch"
    CLIPPING_CAT_CLAWS = "Clipping cat claws"
    PUTTING_ON_MAKEUP = "Putting on makeup"
    HAND_WASHING_CLOTHES = "Hand washing clothes"
    HITTING_A_PINATA = "Hitting a pinata"
    TAI_CHI = "Tai chi"
    GETTING_A_TATTOO = "Getting a tattoo"
    DRINKING_BEER = "Drinking beer"
    SHAVING_LEGS = "Shaving legs"
    DOING_KARATE = "Doing karate"
    PLAYING_RUBIK_CUBE = "Playing rubik cube"
    FAMILY_LIFE = "Family Life"
    ROLLERBLADING = "Rollerblading"
    EDUCATION_AND_COMMUNICATIONS = "Education and Communications"
    FIXING_BICYCLE = "Fixing bicycle"
    BEER_PONG = "Beer pong"
    IRONING_CLOTHES = "Ironing clothes"
    CUTTING_THE_GRASS = "Cutting the grass"
    RAKING_LEAVES = "Raking leaves"
    PLAYING_SQUASH = "Playing squash"
    HOPSCOTCH = "Hopscotch"
    INSTALLING_CARPET = "Installing carpet"
    POLISHING_FURNITURE = "Polishing furniture"
    DECORATING_THE_CHRISTMAS_TREE = "Decorating the Christmas tree"
    PREPARING_SALAD = "Preparing salad"
    PREPARING_PASTA = "Preparing pasta"
    VACUUMING_FLOOR = "Vacuuming floor"
    CLEAN_AND_JERK = "Clean and jerk"
    COMPUTERS_AND_ELECTRONICS = "Computers and Electronics"
    CROQUET = "Croquet"

==> deepeval-2.1.9.tar.gz: deepeval-2.1.9/deepeval/benchmarks/hellaswag/task.py <==
from enum import Enum


class HellaSwagTask(Enum):
    APPLYING_SUNSCREEN = "Applying sunscreen"
    TRIMMING_BRANCHES_OR_HEDGES = "Trimming branches or hedges"
    DISC_DOG = "Disc dog"
    WAKEBOARDING = "Wakeboarding"
    SKATEBOARDING = "Skateboarding"
    WATERSKIING = "Waterskiing"
    WASHING_HANDS = "Washing hands"
    SAILING = "Sailing"
    PLAYING_CONGAS = "Playing congas"
    BALLET = "Ballet"
    ROOF_SHINGLE_REMOVAL = "Roof shingle removal"
    HAND_CAR_WASH = "Hand car wash"
    KITE_FLYING = "Kite flying"
    PLAYING_POOL = "Playing pool"
    PLAYING_LACROSSE = "Playing lacrosse"
    LAYUP_DRILL_IN_BASKETBALL = "Layup drill in basketball"
    HOME_AND_GARDEN = "Home and Garden"
    PLAYING_BEACH_VOLLEYBALL = "Playing beach volleyball"
    CALF_ROPING = "Calf roping"
    SCUBA_DIVING = "Scuba diving"
    MIXING_DRINKS = "Mixing drinks"
    PUTTING_ON_SHOES = "Putting on shoes"
    MAKING_A_LEMONADE = "Making a lemonade"
    UNCATEGORIZED = "Uncategorized"
    ZUMBA = "Zumba"
    PLAYING_BADMINTON = "Playing badminton"
    PLAYING_BAGPIPES = "Playing bagpipes"
    FOOD_AND_ENTERTAINING = "Food and Entertaining"
    PERSONAL_CARE_AND_STYLE = "Personal Care and Style"
    CRICKET = "Cricket"
    SHOVELING_SNOW = "Shoveling snow"
    PING_PONG = "Ping-pong"
    HOLIDAYS_AND_TRADITIONS = "Holidays and Traditions"
    ICE_FISHING = "Ice fishing"
    BEACH_SOCCER = "Beach soccer"
    TABLE_SOCCER = "Table soccer"
    SWIMMING = "Swimming"
    BATON_TWIRLING = "Baton twirling"
    JAVELIN_THROW = "Javelin throw"
    SHOT_PUT = "Shot put"
    DOING_CRUNCHES = "Doing crunches"
    POLISHING_SHOES = "Polishing shoes"
    TRAVEL = "Travel"
    USING_UNEVEN_BARS = "Using uneven bars"
    PLAYING_HARMONICA = "Playing harmonica"
    RELATIONSHIPS = "Relationships"
    HIGH_JUMP = "High jump"
    MAKING_A_SANDWICH = "Making a sandwich"
    POWERBOCKING = "Powerbocking"
    REMOVING_ICE_FROM_CAR = "Removing ice from car"
    SHAVING = "Shaving"
    SHARPENING_KNIVES = "Sharpening knives"
    WELDING = "Welding"
    USING_PARALLEL_BARS = "Using parallel bars"
    HOME_CATEGORIES = "Home,Categories"
    ROCK_CLIMBING = "Rock climbing"
    SNOW_TUBING = "Snow tubing"
    WASHING_FACE = "Washing face"
    ASSEMBLING_BICYCLE = "Assembling bicycle"
    TENNIS_SERVE_WITH_BALL_BOUNCING = "Tennis serve with ball bouncing"
    SHUFFLEBOARD = "Shuffleboard"
    DODGEBALL = "Dodgeball"
    CAPOEIRA = "Capoeira"
    PAINTBALL = "Paintball"
    DOING_A_POWERBOMB = "Doing a powerbomb"
    DOING_MOTOCROSS = "Doing motocross"
    PLAYING_ICE_HOCKEY = "Playing ice hockey"
    PHILOSOPHY_AND_RELIGION = "Philosophy and Religion"
    ARCHERY = "Archery"
    CARS_AND_OTHER_VEHICLES = "Cars & Other Vehicles"
    RUNNING_A_MARATHON = "Running a marathon"
    THROWING_DARTS = "Throwing darts"
    PAINTING_FURNITURE = "Painting furniture"
    HAVING_AN_ICE_CREAM = "Having an ice cream"
    SLACKLINING = "Slacklining"
    CAMEL_RIDE = "Camel ride"
    ARM_WRESTLING = "Arm wrestling"
    HULA_HOOP = "Hula hoop"
    SURFING = "Surfing"
    PLAYING_PIANO = "Playing piano"
    GARGLING_MOUTHWASH = "Gargling mouthwash"
    PLAYING_ACCORDION = "Playing accordion"
    HORSEBACK_RIDING = "Horseback riding"
    PUTTING_IN_CONTACT_LENSES = "Putting in contact lenses"
    PLAYING_SAXOPHONE = "Playing saxophone"
    FUTSAL = "Futsal"
    LONG_JUMP = "Long jump"
    LONGBOARDING = "Longboarding"
    POLE_VAULT = "Pole vault"
    BUILDING_SANDCASTLES = "Building sandcastles"
    PLATFORM_DIVING = "Plataform diving"
    PAINTING = "Painting"
    SPINNING = "Spinning"
    CARVING_JACK_O_LANTERNS = "Carving jack-o-lanterns"
    BRAIDING_HAIR = "Braiding hair"
    YOUTH = "Youth"
    PLAYING_VIOLIN = "Playing violin"
    CANOEING = "Canoeing"
    CHEERLEADING = "Cheerleading"
    PETS_AND_ANIMALS = "Pets and Animals"
    KAYAKING = "Kayaking"
    CLEANING_SHOES = "Cleaning shoes"
    KNITTING = "Knitting"
    BAKING_COOKIES = "Baking cookies"
    DOING_FENCING = "Doing fencing"
    PLAYING_GUITARRA = "Playing guitarra"
    USING_THE_ROWING_MACHINE = "Using the rowing machine"
    GETTING_A_HAIRCUT = "Getting a haircut"
    MOOPING_FLOOR = "Mooping floor"
    RIVER_TUBING = "River tubing"
    CLEANING_SINK = "Cleaning sink"
    GROOMING_DOG = "Grooming dog"
    DISCUS_THROW = "Discus throw"
    CLEANING_WINDOWS = "Cleaning windows"
    FINANCE_AND_BUSINESS = "Finance and Business"
    HANGING_WALLPAPER = "Hanging wallpaper"
    ROPE_SKIPPING = "Rope skipping"
    WINDSURFING = "Windsurfing"
    KNEELING = "Kneeling"
    GETTING_A_PIERCING = "Getting a piercing"
    ROCK_PAPER_SCISSORS = "Rock-paper-scissors"
    SPORTS_AND_FITNESS = "Sports and Fitness"
    BREAKDANCING = "Breakdancing"
    WALKING_THE_DOG = "Walking the dog"
    PLAYING_DRUMS = "Playing drums"
    PLAYING_WATER_POLO = "Playing water polo"
    BMX = "BMX"
    SMOKING_A_CIGARETTE = "Smoking a cigarette"
    BLOWING_LEAVES = "Blowing leaves"
    BULLFIGHTING = "Bullfighting"
    DRINKING_COFFEE = "Drinking coffee"
    BATHING_DOG = "Bathing dog"
    TANGO = "Tango"
    WRAPPING_PRESENTS = "Wrapping presents"
    PLASTERING = "Plastering"
    PLAYING_BLACKJACK = "Playing blackjack"
    FUN_SLIDING_DOWN = "Fun sliding down"
    WORK_WORLD = "Work World"
    TRIPLE_JUMP = "Triple jump"
    TUMBLING = "Tumbling"
    SKIING = "Skiing"
    DOING_KICKBOXING = "Doing kickboxing"
    BLOW_DRYING_HAIR = "Blow-drying hair"
    DRUM_CORPS = "Drum corps"
    SMOKING_HOOKAH = "Smoking hookah"
    MOWING_THE_LAWN = "Mowing the lawn"
    VOLLEYBALL = "Volleyball"
    LAYING_TILE = "Laying tile"
    STARTING_A_CAMPFIRE = "Starting a campfire"
    SUMO = "Sumo"
    HURLING = "Hurling"
    PLAYING_KICKBALL = "Playing kickball"
    MAKING_A_CAKE = "Making a cake"
    FIXING_THE_ROOF = "Fixing the roof"
    PLAYING_POLO = "Playing polo"
    REMOVING_CURLERS = "Removing curlers"
    ELLIPTICAL_TRAINER = "Elliptical trainer"
    HEALTH = "Health"
    SPREAD_MULCH = "Spread mulch"
    CHOPPING_WOOD = "Chopping wood"
    BRUSHING_TEETH = "Brushing teeth"
    USING_THE_POMMEL_HORSE = "Using the pommel horse"
    SNATCH = "Snatch"
    CLIPPING_CAT_CLAWS = "Clipping cat claws"
    PUTTING_ON_MAKEUP = "Putting on makeup"
    HAND_WASHING_CLOTHES = "Hand washing clothes"
    HITTING_A_PINATA = "Hitting a pinata"
    TAI_CHI = "Tai chi"
    GETTING_A_TATTOO = "Getting a tattoo"
    DRINKING_BEER = "Drinking beer"
    SHAVING_LEGS = "Shaving legs"
    DOING_KARATE = "Doing karate"
    PLAYING_RUBIK_CUBE = "Playing rubik cube"
    FAMILY_LIFE = "Family Life"
    ROLLERBLADING = "Rollerblading"
    EDUCATION_AND_COMMUNICATIONS = "Education and Communications"
    FIXING_BICYCLE = "Fixing bicycle"
    BEER_PONG = "Beer pong"
    IRONING_CLOTHES = "Ironing clothes"
    CUTTING_THE_GRASS = "Cutting the grass"
    RAKING_LEAVES = "Raking leaves"
    PLAYING_SQUASH = "Playing squash"
    HOPSCOTCH = "Hopscotch"
    INSTALLING_CARPET = "Installing carpet"
    POLISHING_FURNITURE = "Polishing forniture"
    DECORATING_THE_CHRISTMAS_TREE = "Decorating the Christmas tree"
    PREPARING_SALAD = "Preparing salad"
    PREPARING_PASTA = "Preparing pasta"
    VACUUMING_FLOOR = "Vacuuming floor"
    CLEAN_AND_JERK = "Clean and jerk"
    COMPUTERS_AND_ELECTRONICS = "Computers and Electronics"
    CROQUET = "Croquet"
